@@ -17,6 +17,6 @@
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --
 
-UPDATE subaward_forms
-SET form = NULL
-WHERE FORM_ID IN ('FDP_AFOSR', 'FDP_AMRMC', 'FDP_AMRAA', 'FDP_ARO', 'FDP_DOE', 'FDP_EPA', 'FDP_NASA', 'FDP_NIH', 'FDP_NSF', 'FDP_ONR', 'FDP_USDA');
+ALTER TABLE SUBAWARD_TEMPLATE_INFO
+  ADD COLUMN (
+  FINAL_STATEMENT_DUE_CD VARCHAR(4));
